Data from a study to define the nasal microbiome of hospital inpatients who are persistently colonized with methicillin-resistant Staphylococcus aureus (MRSA) compared with matched, non-colonized controls. See original paper for matching proceedure.
mrsa_genA 34x75 data.frame
OTU_NameA character vector of class level OTU names
Lib namesThe following columns are the sequencing counts for each library with library names