# NOT RUN {
data(phy); data(cla); data(ord); data(fam); data(clin)
otu_tabs <- list(Phylum = phy, Class = cla, Order = ord, Family = fam)
set <- tidy_micro(otu_tabs = otu_tabs, clinical = clin) %>%
mutate(bpd1 = factor(bpd1))
## Summarize each taxa by Table
set %>% taxa_summary
## Summarize each taxa by a categorical variable of interest
set %>% taxa_summary(bpd1)
## Summarize each taxa by a categorical variable of interest within a Table
set %>% taxa_summary(bpd1, table = "Phylum")
## Summarize within group or table only
set %>% taxa_summary(taxa = FALSE)
# }
Run the code above in your browser using DataLab