# NOT RUN {
data(phy); data(cla); data(ord); data(fam); data(clin)
## Multiple OTU tables with named list
otu_tabs <- list(Phylum = phy, Class = cla, Order = ord, Family = fam)
set <- tidy_micro(otu_tabs = otu_tabs, clinical = clin)
## Multiple OTU tables with unnamed list
unnamed_tabs <- list(phy,cla,ord,fam)
set <- tidy_micro(otu_tabs = unnamed_tabs,
tab_names = c("Phylum", "Class", "Order", "Family"), clinical = clin)
## Single OTU table
set <- tidy_micro(otu_tabs = cla, tab_names = "Class", clinical = clin)
## Filtering out low abundance or uninteresting taxa right away
## WARNING: Only do this if you do not want to calculate alpha diversities with this micro_set
filter_set <- tidy_micro(otu_tabs = otu_tabs, clinical = clin,
prev_cutoff = 5, ## 5% of libraries must have this bug, or it is filtered
ra_cutoff = 1, ## At least 1 libraries must have RA of 1, or it is filtered
exclude_taxa = c("Unclassified", "Bacteria") ## Unclassified taxa we don't want
)
# }
Run the code above in your browser using DataLab